@@ -24,13 +24,13 @@ class RiteAidAPI:
     async def refill_rx(prescription_nums, store_id, date, time, phone):
         """Refill a prescription."""
         # Using application/x-www-form-urlencoded
-        form = quote("refillPrescriptions={}&location={}&pickUpDate={}&pickUpTime={}&phone={}".format(
-            json.dumps(prescription_nums),
-            store_id,
-            date,
-            time,
-            phone
-        ))
+        form = "refillPrescriptions={}&location={}&pickUpDate={}&pickUpTime={}&phone={}".format(
+            quote(json.dumps(prescription_nums)),
+            quote(store_id),
+            quote(date),
+            quote(time),
+            quote(phone),
+        )
         async with aiohttp.ClientSession() as session:
             async with session.post(REFILL_RX_URL, data=form) as resp:
                 return await resp.json()
\ No newline at end of file
